/*
 * French Revolutionary Calendar Android Widget
 * Copyright (C) 2016 Carmen Alvarez
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */

package ca.rmen.android.frccommon.compat;

import android.annotation.TargetApi;
import android.app.Notification;
import android.app.PendingIntent;
import android.content.Context;

import ca.rmen.android.frccommon.Action;

@TargetApi(16)
class Api16Helper {
    private static final String PREF_SETTING_SYSTEM_NOTIFICATION_PRIORITY_MAX = "max";
    private static final String PREF_SETTING_SYSTEM_NOTIFICATION_PRIORITY_HIGH = "high";
    private static final String PREF_SETTING_SYSTEM_NOTIFICATION_PRIORITY_LOW = "low";
    private static final String PREF_SETTING_SYSTEM_NOTIFICATION_PRIORITY_MIN = "min";

    private Api16Helper() {
        // prevent instantiation
    }

    static int getNotificationPriority(String priorityPref) {
        if (priorityPref.equals(PREF_SETTING_SYSTEM_NOTIFICATION_PRIORITY_MAX)) return Notification.PRIORITY_MAX;
        if (priorityPref.equals(PREF_SETTING_SYSTEM_NOTIFICATION_PRIORITY_HIGH)) return Notification.PRIORITY_HIGH;
        if (priorityPref.equals(PREF_SETTING_SYSTEM_NOTIFICATION_PRIORITY_LOW)) return Notification.PRIORITY_LOW;
        if (priorityPref.equals(PREF_SETTING_SYSTEM_NOTIFICATION_PRIORITY_MIN)) return Notification.PRIORITY_MIN;
        return Notification.PRIORITY_DEFAULT;
    }

    static Notification createNotification(
            Context context,
            int priority,
            int iconId,
            String tickerText,
            String contentText,
            String bigText,
            PendingIntent defaultIntent,
            Action... actions) {
        Notification.Builder builder = new Notification.Builder(context)
                .setPriority(priority)
                .setAutoCancel(true)
                .setContentTitle(tickerText)
                .setContentText(contentText)
                .setStyle(new Notification.BigTextStyle().bigText(bigText))
                .setSmallIcon(iconId)
                .setContentIntent(defaultIntent);

        for (Action action : actions) {
            //noinspection deprecation
            builder.addAction(action.iconId, action.title, action.pendingIntent);
        }
        return builder.build();
    }

}
